fmrb is the Python package supporting both common and domain-specific needs of
the `FMR Challenge <http://fmrchallenge.org>`_. The sources are maintained in
the fmrbenchmark repository at https://github.com/fmrchallenge/fmrbenchmark
A good place to begin is the README there or the User's Guide, the current
release of which is at http://docs.fmrchallenge.org
